
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    print qq{1..0 # SKIP these tests are for testing by the author\n};
    exit
  }
}

use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
Abhijit
Attachment
Client
Damien
Dean
Dmitri
Exception
Forms
Group
HTTPClient
Hamstead
JLMARTIN
Krotkine
Menon
Miquel
Object
Queue
REST
RT
Ruiz
SRVSH
SearchResult
Ticket
Tikhonov
Transaction
User
ams
dams
dean
dtikhonov
lib
mruiz
